@@ -117,7 +117,7 @@ class IDBC:
                                 this_sig.factor = f_factor
                                 this_sig.offset = f_offset
                                 this_sig.length_bit = int(f_length_bit)
-                                this_sig.start_bit = int(f_start_bit)
+                                this_sig.start_bit = int(f_start_bit) - int(f_length_bit) + 1
                                 f_now_msg.signal_list.append(this_sig)
                         if f_line.startswith("BA_ \"GenSigStartValue\""):  # 得到信号的默认值
                             f_tokens = f_line.split(' ')
